@@ -1,5 +1,5 @@
 package Catalyst::Controller::DBIC::API::RequestArguments;
-our $VERSION = '2.001001';
+our $VERSION = '2.001002';
 
 #ABSTRACT: Provides Request argument validation
 use MooseX::Role::Parameterized;
@@ -67,6 +67,15 @@ role {
     );
 
 
+    has 'offset' =>
+    (
+        is => 'ro',
+        writer => '_set_offset',
+        isa => Int,
+        predicate => 'has_offset',
+    );
+
+
     has 'ordered_by' =>
     (
         is => 'ro',
@@ -344,9 +353,10 @@ role {
             $self->_set_as($new->{$controller->as_arg}) if exists $new->{$controller->as_arg};
             $self->_set_grouped_by($new->{$controller->grouped_by_arg}) if exists $new->{$controller->grouped_by_arg};
             $self->_set_ordered_by($new->{$controller->ordered_by_arg}) if exists $new->{$controller->ordered_by_arg};
-            $self->_set_search($new->{$controller->search_arg}) if exists $new->{$controller->search_arg};
             $self->_set_count($new->{$controller->count_arg}) if exists $new->{$controller->count_arg};
             $self->_set_page($new->{$controller->page_arg}) if exists $new->{$controller->page_arg};
+            $self->_set_offset($new->{$controller->offset_arg}) if exists $new->{$controller->offset_arg};
+            $self->_set_search($new->{$controller->search_arg}) if exists $new->{$controller->search_arg};
         }
     );
 
@@ -429,10 +439,21 @@ role {
             as => $self->as || ((scalar(@{$static->as})) ? $static->as : undef),
             prefetch => $self->prefetch || $static->prefetch || undef,
             rows => $self->count || $static->count,
-            page => $self->page,
+            offset => $self->offset,
             join => $self->build_joins,
         };
 
+        if($self->has_page)
+        {
+            $search_attributes->{page} = $self->page;
+        }
+        elsif(!$self->has_page && defined($search_attributes->{offset}) && defined($search_attributes->{rows}))
+        {
+            $search_attributes->{page} = $search_attributes->{offset} / $search_attributes->{rows} + 1;
+            delete $search_attributes->{offset};
+        }
+        
+
         $search_attributes = 
         {   
             map { @$_ }
@@ -480,7 +501,7 @@ Catalyst::Controller::DBIC::API::RequestArguments - Provides Request argument va
 
 =head1 VERSION
 
-version 2.001001
+version 2.001002
 
 =head1 DESCRIPTION
 
@@ -496,6 +517,10 @@ count is the number of rows to be returned during paging
 
 page is what page to return while paging
 
+=head2 offset is ro, isa: Int
+
+offset specifies where to start the paged result (think SQL LIMIT)
+
 =head2 ordered_by is: ro, isa: L<Catalyst::Controller::DBIC::API::Types/OrderedBy>
 
 ordered_by is passed to ->search to determine sorting
